mlbench_core.utils
------------------
.. autoapimodule:: mlbench_core.utils
.. currentmodule:: mlbench_core.utils

pytorch
~~~~~~~

.. autoapimodule:: mlbench_core.utils.pytorch
.. currentmodule:: mlbench_core.utils.pytorch


FCGraph
'''''''

.. autoapiclass:: FCGraph
    :members:

initialize_backends
'''''''''''''''''''

.. autoapifunction:: initialize_backends


Checkpointer
''''''''''''

.. autoapimodule:: mlbench_core.utils.pytorch.checkpoint
.. currentmodule:: mlbench_core.utils.pytorch.checkpoint

.. autoapiclass:: Checkpointer


Distributed
'''''''''''

.. autoapimodule:: mlbench_core.utils.pytorch.distributed
.. currentmodule:: mlbench_core.utils.pytorch.distributed

.. autoapiclass:: Aggregation
    :members:
    :private-members:
    :undoc-members:

.. autoapiclass:: AllReduceAggregation
    :show-inheritance:
    :private-members:

.. autoapiclass:: DecentralizedAggregation
    :show-inheritance:
    :private-members:

.. autoapiclass:: SparsifiedAggregation
    :show-inheritance:
    :private-members:

.. autoapifunction:: pack_tensors

.. autoapifunction:: unpack_tensors


Inference
'''''''''

.. autoapimodule:: mlbench_core.utils.pytorch.inference
.. currentmodule:: mlbench_core.utils.pytorch.inference

Translator
++++++++++

.. autoapiclass:: Translator
    :members:

BeamSearch
++++++++++

.. autoapimodule:: mlbench_core.utils.pytorch.inference.beam_search
    :members:


tensorflow
~~~~~~~~~~

.. autoapimodule:: mlbench_core.utils.tensorflow
.. currentmodule:: mlbench_core.utils.tensorflow


